.. _installation:

Installation
============

You can use ``pip`` to install ``vedis-python``:

.. code-block:: console

    pip install vedis

The project is hosted at https://github.com/coleifer/vedis-python and can be installed from source:

.. code-block:: console

    git clone https://github.com/coleifer/vedis-python
    cd vedis-python
    python setup.py build
    python setup.py install

After installing vedis-python, you can run the unit tests by executing the `vedis.tests` module:

.. code-block:: console

    python vedis/tests.py
